<?php

/**
 * 内部リンク用ブログカード
 * @since 1.0.0
 * @return string
 */
function stbl_get_card_link_callback($attributes) {

	if (empty($attributes['postId'])) return '';

	$post_id   = $attributes['postId'];
	$post_data = get_post($post_id);

	if (empty($post_data)) return '<p class="stbl-card-link__notfound">記事が見つかりませんでした。</p>';

	$selected_style = !empty($attributes["className"]) ? $attributes["className"] : 'is-style-default';
	$class_name = 'stbl-card-link ' . $selected_style;
	$title     = get_the_title($post_id);
	$title     = stbl_mb_substr_text($title, 50);
	$url       = get_permalink($post_id);
	$excerpt   = stbl_get_excerpt($post_id, 140, false);
	$thumb_src = stbl_get_thumbnail_url($post_id, 'medium');

	$max_width = isset( $attributes["maxWidth"] ) && ! empty( $attributes["maxWidth"] )
		? $attributes["maxWidth"] : 'none';

	$color_vars = '';

	if ( isset($attributes["borderColor"]) && $attributes["borderColor"] ) {
		$color_vars .= '--stbl-card-link-border-color:' . $attributes["borderColor"] . ';';
	}
	if ( isset($attributes["backgroundColor"]) && $attributes["backgroundColor"] ) {
		$color_vars .= '--stbl-card-link-background-color:' . $attributes["backgroundColor"] . ';';
	}

	ob_start();
	?>
	
	<a class="<?php echo $class_name; ?>" href="<?php echo $url; ?>" style="max-width: <?php echo $max_width; ?>; <?php echo $color_vars; ?>">
		<figure class="stbl-card-link__thumb">
			<img src="<?php echo $thumb_src; ?>" alt="<?php echo $title; ?>" loading="lazy" />
		</figure>
		<div class="stbl-card-link__body">
			<p class="stbl-card-link__ttl"><?php echo $title; ?></p>
			<p class="stbl-card-link__excerpt"><?php echo $excerpt; ?></p>
		</div>
	</a>
	<?php

	$content = ob_get_clean();

	return $content;
}

function stbl_register_block_original_card_link() {
	register_block_type('streetist-blocks/card-link', array(
		'editor_script' => 'editor-script-streetist-blocks',
		'editor_style' => 'editor-style-streetist-blocks',
		'script' => 'script-streetist-blocks',
		'style' => 'style-streetist-blocks',
		'attributes' 	=> array(
			'postId' => array(
				'type' => 'string',
			),
			'maxWidth' => array(
				'type' => 'string',
			),
			'borderColor' => array(
				'type' => 'string',
			),
			'backgroundColor' => array(
				'type' => 'string',
				'default' => '#ffffff',
			),
		),
		'render_callback'	=> 'stbl_get_card_link_callback',
	));
}
add_action('init', 'stbl_register_block_original_card_link');